![PTTLibrary: A PTT Library in Python](https://raw.githubusercontent.com/Truth0906/PTTLibrary/master/logo/facebook_cover_photo_1.png)
# PTT Library
[![Python 3.6](https://img.shields.io/badge/python-3.6-blue.svg)](https://www.python.org/downloads/release/python-360/)
[![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary)
[![Build Status](https://travis-ci.org/PttCodingMan/PTTLibrary.svg?branch=master)](https://travis-ci.org/PttCodingMan/PTTLibrary)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/c52adb27e96f49d4841df3fb6fbe1d5e)](https://www.codacy.com/manual/PttCodingMan/PTTLibrary?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PTTLibrary&amp;utm_campaign=Badge_Grade)
![license](https://img.shields.io/github/license/mashape/apistatus.svg)
[![Join the chat at https://gitter.im/PTTLibrary/Lobby](https://badges.gitter.im/PTTLibrary/Lobby.svg)](https://gitter.im/PTTLibrary/Lobby?utm_source=badge&utm_medium=badge&utm_content=badge)
[![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)

#### PTT Library 是一套使用 Python 開發的 PTT API。具備大部分常用功能，無論推文、發文、爬蟲、寄信、發 P 幣、丟水球或者追蹤帳號，你都可以在這裡找到完整的使用範例
#### 採用最新支援的 WebSocket 連線協定，並且支援繁體中文與英文顯示，在僅支援英文的作業系統也沒有問題
#### API 的詳細範例與參數說明 [PTT Library 手冊](https://hackmd.io/@CodingMan/PTTLibraryManual)
#### 測試平台: Windows 10, Ubuntu 18.04, MacOS 10.14
#### Pypi: https://pypi.org/project/PTTLibrary/
<img src="https://i.imgur.com/wfaf8Bk.gif" width="480">

## 為什麼選擇 PTT Library
#### 完整的支援: PTT Library 是目前支援最完整的 PTT API，除了 PTT 也相容於 PTT2，詳細範例請參考 [PTT Library 手冊](https://hackmd.io/@CodingMan/PTTLibraryManual)
#### 高效能爬蟲: 首創登入式爬蟲，除了可以取得最即時的推文，並且比網頁式爬蟲擁有更好的效能 [效能比較表](https://hackmd.io/@CodingMan/crawlerbenchmark)
#### 快速的客服: 如果遇到問題你可以在 [![Join the chat at https://gitter.im/PTTLibrary/Lobby](https://badges.gitter.im/PTTLibrary/Lobby.svg)](https://gitter.im/PTTLibrary/Lobby?utm_source=badge&utm_medium=badge&utm_content=badge) 找到我
#### 完整的測試: 每一次有新的 push，CI 都會自動開始測試，你可以在 [![Build Status](https://travis-ci.org/PttCodingMan/PTTLibrary.svg?branch=master)](https://travis-ci.org/PttCodingMan/PTTLibrary) 找到測試結果
#### 良好程式碼品質: 你可以在 [![Codacy Badge](https://api.codacy.com/project/badge/Grade/c52adb27e96f49d4841df3fb6fbe1d5e)](https://www.codacy.com/manual/PttCodingMan/PTTLibrary?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=PttCodingMan/PTTLibrary&amp;utm_campaign=Badge_Grade) 找到程式碼品質報告與等級

## 版本
#### [![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary)

## 取得
#### 安裝
#### Windows 使用 pip, Linux and Mac 使用 pip3
```bash
pip install PTTLibrary
```

## 回報問題
#### 1. 請閱讀 [PTT Library 手冊](https://hackmd.io/@CodingMan/PTTLibraryManual) 確認使用方法無誤並確認你所使用的版本為 [![Package Version](https://img.shields.io/pypi/v/PTTLibrary.svg)](https://pypi.python.org/pypi/PTTLibrary) 如果是舊版本請更新後複測
#### 2. 如果問題還是存在，請參考手冊中的 [初始設定](https://hackmd.io/JAiqhriyQVe_TJleNwLWTQ#%E5%88%9D%E5%A7%8B%E8%A8%AD%E5%AE%9A) 將 Log level 調整成 TRACE 後截圖並附上 PTT Library 的相關程式碼
#### 3. 開個 [issue](https://github.com/Truth0906/PTTLibrary/issues/new) 追蹤問題也可以直接在 gitter 上問我 [![Join the chat at https://gitter.im/PTTLibrary/Lobby](https://badges.gitter.im/PTTLibrary/Lobby.svg)](https://gitter.im/PTTLibrary/Lobby?utm_source=badge&utm_medium=badge&utm_content=badge)

## 需求
#### Python ≥ 3.6

## 相依函式庫
#### progressbar2
#### websockets
#### uao
#### beautifulsoup4 (Since 0.8.25)
#### requests (Since 0.8.25)

## 贊助
#### 在這個 github 的小園地，用熱血的心為您打造在 PTT 翱翔的翅膀
#### 希望您可以贊助這雙翅膀，讓我們一起飛得更遠
####
#### [![Donate](https://img.shields.io/badge/Donate-PayPal-green.svg)](http://paypal.me/CodingMan)
####
#### XMR
#### 448CUe2q4Ecf9tx6rwanrqM9kfCwqpNbhJ5jtrTf9FHqHNq7Lvv9uBoQ74SEaAu9FFceNBr6p3W1yhqPcxPPSSTv2ctufnQ

## 贊助清單

#### 尚無贊助
